@@ -1,11 +1,13 @@
 var NAVTREEINDEX12 =
 {
+"classFl__Widget.html#a37aa870315e37ddc1246caa6421322f4":[4,0,142,68],
 "classFl__Widget.html#a3b8dfdcc9bf9f375fc889a9420a24564":[4,0,142,74],
 "classFl__Widget.html#a3eb3b128cbad3f579a66cab813470442":[4,0,142,33],
 "classFl__Widget.html#a41d417d5350306a6fb2154300b73d436":[4,0,142,122],
 "classFl__Widget.html#a42372b96b98b126a211b88dc935c2ae6":[4,0,142,86],
 "classFl__Widget.html#a4288bfa92dadf31956e2f14f9bfeff5e":[4,0,142,48],
 "classFl__Widget.html#a437f8c2faa16f9811f544b46372cbbc2":[4,0,142,110],
+"classFl__Widget.html#a451e48c276768108a27a32b122e95b04":[4,0,142,124],
 "classFl__Widget.html#a454a0be4839ea5ed2aa203d788bf840f":[4,0,142,38],
 "classFl__Widget.html#a464c6760c08e56cf53338398e5bc60f4":[4,0,142,36],
 "classFl__Widget.html#a4891c252ad3005abef5f4cb831d4b854":[4,0,142,79],
@@ -13,13 +15,13 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#a4aad2627795bfbe0d093b1fbcd87e67e":[4,0,142,28],
 "classFl__Widget.html#a4b3849897d55073256ab98e46298afd9":[4,0,142,26],
 "classFl__Widget.html#a5450e5156a76c273e67ef09225c9615b":[4,0,142,50],
-"classFl__Widget.html#a54fbdc7be9ae81c6b34abc73a93908f1":[4,0,142,141],
+"classFl__Widget.html#a54fbdc7be9ae81c6b34abc73a93908f1":[4,0,142,143],
 "classFl__Widget.html#a5934aae6f86145fd40e65b35c12df0dc":[4,0,142,62],
 "classFl__Widget.html#a5951fcf543a56357c2375657c7db6314":[4,0,142,34],
 "classFl__Widget.html#a5ab161ab774b29946049a44d575b363d":[4,0,142,53],
 "classFl__Widget.html#a60e13c7f4ead4f0c543d1c8b7582be8c":[4,0,142,76],
 "classFl__Widget.html#a645c3112dc8c242b099ef8aee45fe7ee":[4,0,142,35],
-"classFl__Widget.html#a6a2a0769c73831e6ef0076d9efa98d72":[4,0,142,130],
+"classFl__Widget.html#a6a2a0769c73831e6ef0076d9efa98d72":[4,0,142,132],
 "classFl__Widget.html#a6ae4e0f8e0c3d78ec47cf0ab85a9644a":[4,0,142,29],
 "classFl__Widget.html#a6b57ff665a0e988064cb42d742668566":[4,0,142,105],
 "classFl__Widget.html#a703b56d2fcb2c31e1bd7d064af444a78":[4,0,142,25],
@@ -37,9 +39,9 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#a8b1d87835f357496bf7dd92e059221e1":[4,0,142,43],
 "classFl__Widget.html#a8b8d231929f3a5f5726811af50161ec9":[4,0,142,92],
 "classFl__Widget.html#a8bf5537fae51a9891a330d4c6b6e499b":[4,0,142,70],
-"classFl__Widget.html#a8e786561b8670afd0b4a582de5087905":[4,0,142,132],
+"classFl__Widget.html#a8e786561b8670afd0b4a582de5087905":[4,0,142,134],
 "classFl__Widget.html#a932f1c090154ba6ccdd9ea18250e7c71":[4,0,142,101],
-"classFl__Widget.html#a94d0d92ae03a8ba20eb42efa2dd2831d":[4,0,142,142],
+"classFl__Widget.html#a94d0d92ae03a8ba20eb42efa2dd2831d":[4,0,142,144],
 "classFl__Widget.html#a952fe0471023401e2efacd69bd2b57e6":[4,0,142,114],
 "classFl__Widget.html#a96634cc3f31c59e7c489c679934a9cd3":[4,0,142,65],
 "classFl__Widget.html#a991d448d9a42fb926819defc9de90999":[4,0,142,37],
@@ -52,7 +54,7 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#aa63ce68cbf4620cf8750b868368ea02b":[4,0,142,107],
 "classFl__Widget.html#aad980d813b8a47d777bde7cfa6b85eae":[4,0,142,30],
 "classFl__Widget.html#aadbbe3d4c1597fa2ed5a9dd8c4749788":[4,0,142,95],
-"classFl__Widget.html#ab194069add839e0aecbc541017c8d383":[4,0,142,135],
+"classFl__Widget.html#ab194069add839e0aecbc541017c8d383":[4,0,142,137],
 "classFl__Widget.html#ab1fe36207b4a59cae3796b0e6d3b7df8":[4,0,142,119],
 "classFl__Widget.html#ab2b89e03832a172d7648dabe0910b038":[4,0,142,42],
 "classFl__Widget.html#ab49565fabce4b04f7ee86d862402a060":[4,0,142,57],
@@ -61,16 +63,17 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#abb0e926996f83bc1c60972afa8284045":[4,0,142,91],
 "classFl__Widget.html#abbd4f11b53ba045345cb3815b002076a":[4,0,142,121],
 "classFl__Widget.html#abd83334100f22d5880cf34a233a35831":[4,0,142,45],
-"classFl__Widget.html#abea0b9ad493d58bf7fda8d3c81d477b7":[4,0,142,138],
-"classFl__Widget.html#ac0b2f353f8d142156ffb27b76a2e9628":[4,0,142,129],
-"classFl__Widget.html#ac3050e16d7ed8dccbbf3468ea8c64ab8":[4,0,142,124],
+"classFl__Widget.html#abd86575e789690f098b953070489cd1d":[4,0,142,125],
+"classFl__Widget.html#abea0b9ad493d58bf7fda8d3c81d477b7":[4,0,142,140],
+"classFl__Widget.html#ac0b2f353f8d142156ffb27b76a2e9628":[4,0,142,131],
+"classFl__Widget.html#ac3050e16d7ed8dccbbf3468ea8c64ab8":[4,0,142,126],
 "classFl__Widget.html#ac45bdb80c3e66c571d0420ebefd4aaa5":[4,0,142,106],
 "classFl__Widget.html#ac55bdb496a01fcbcad924f1cec506798":[4,0,142,73],
 "classFl__Widget.html#ac58ffabf428d0589327e01e0ec740dc5":[4,0,142,77],
 "classFl__Widget.html#ac92191cba5d17ae34bfc346d2126c9f2":[4,0,142,61],
 "classFl__Widget.html#aca0164a60a96b07007cc1f78bd6d2140":[4,0,142,24],
 "classFl__Widget.html#aca98267e7a9b94f699ebd27d9f59e8bb":[4,0,142,109],
-"classFl__Widget.html#acb46c71f55ccdfeead9e9dcb3fb2c23b":[4,0,142,136],
+"classFl__Widget.html#acb46c71f55ccdfeead9e9dcb3fb2c23b":[4,0,142,138],
 "classFl__Widget.html#acd8a95e8128fe1673479b8d0f4d0aa62a00340c90b72c9487fedd12da4da50f21":[4,0,142,8],
 "classFl__Widget.html#acd8a95e8128fe1673479b8d0f4d0aa62a0e4b0ee03d96b193e35db4acbd33dc34":[4,0,142,17],
 "classFl__Widget.html#acd8a95e8128fe1673479b8d0f4d0aa62a131121d89e9c73bc4c2de9e58ecd9976":[4,0,142,21],
@@ -96,10 +99,10 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#acd8a95e8128fe1673479b8d0f4d0aa62afa54ec676a879041361189cc8de88b57":[4,0,142,2],
 "classFl__Widget.html#ace94ae2916d23e563bf30fb5bdab9aad":[4,0,142,60],
 "classFl__Widget.html#acf82200fdfe16a2e0bd9d3ee58e44958":[4,0,142,116],
-"classFl__Widget.html#ad00d1457b3f578c8e6ffca52d9facad8":[4,0,142,125],
-"classFl__Widget.html#ad09bc10de43482a671f834a653211e9f":[4,0,142,139],
+"classFl__Widget.html#ad00d1457b3f578c8e6ffca52d9facad8":[4,0,142,127],
+"classFl__Widget.html#ad09bc10de43482a671f834a653211e9f":[4,0,142,141],
 "classFl__Widget.html#ad4a38af32c73871b177ca4d482997e46":[4,0,142,103],
-"classFl__Widget.html#ad59ece778aaf15acc4dd01a8bf5f8012":[4,0,142,133],
+"classFl__Widget.html#ad59ece778aaf15acc4dd01a8bf5f8012":[4,0,142,135],
 "classFl__Widget.html#ad5fe4ff0d0f777af13f3d8818c869689":[4,0,142,40],
 "classFl__Widget.html#ad7cdc363b24014d5c518c4f1231aff94":[4,0,142,44],
 "classFl__Widget.html#ad7eb0fb6309d995f240b9b9476f3b2c6":[4,0,142,98],
@@ -109,13 +112,13 @@ var NAVTREEINDEX12 =
 "classFl__Widget.html#ae2fbf2e7056a07cd0e1e23ece102ce87":[4,0,142,56],
 "classFl__Widget.html#ae386844a68c27ea0b64313619551e786":[4,0,142,118],
 "classFl__Widget.html#ae9bfda1ebdcbf0946aef558b9d9f0e3c":[4,0,142,55],
-"classFl__Widget.html#aec1aded9efdf5f23dfac8cc725cefc4a":[4,0,142,140],
-"classFl__Widget.html#aec9e0a6f77d93e6f8caffc1b0f6abbda":[4,0,142,134],
+"classFl__Widget.html#aec1aded9efdf5f23dfac8cc725cefc4a":[4,0,142,142],
+"classFl__Widget.html#aec9e0a6f77d93e6f8caffc1b0f6abbda":[4,0,142,136],
 "classFl__Widget.html#aed4cb72875f7a3a5b14dec33d78cb4e3":[4,0,142,47],
 "classFl__Widget.html#aeeabd61e2d10c76cd6600dbbfe951f71":[4,0,142,82],
-"classFl__Widget.html#aeeef6f7148baff5b85cc50e1a34e6a13":[4,0,142,126],
+"classFl__Widget.html#aeeef6f7148baff5b85cc50e1a34e6a13":[4,0,142,128],
 "classFl__Widget.html#af5a91645a4735db51626a2e273c04bb9":[4,0,142,58],
-"classFl__Widget.html#af8834d376878616c66a094cad6fec9d2":[4,0,142,137],
+"classFl__Widget.html#af8834d376878616c66a094cad6fec9d2":[4,0,142,139],
 "classFl__Widget.html#af9942c4d795ec12c7c1ec1ce5e665a01":[4,0,142,46],
 "classFl__Widget.html#aff29d81e64b617158472f38d2cac186e":[4,0,142,89],
 "classFl__Widget__Tracker.html":[4,0,143],
@@ -211,43 +214,40 @@ var NAVTREEINDEX12 =
 "classFl__Xlib__Graphics__Driver.html#ae88164fde82dfcf8fa3caa3b7fe75248":[4,0,148,14],
 "classFl__Xlib__Graphics__Driver.html#af916ef3a5ec09ee062b6f193a14a63c8":[4,0,148,5],
 "classFl__Xlib__Graphics__Driver.html#afed43a24d5b06da63608eb5ac5349798":[4,0,148,2],
-"classIActiveIMMApp.html":[4,0,150],
-"classIActiveIMMApp.html#a0540bef97db74c1803ee1a513277799d":[4,0,150,62],
-"classIActiveIMMApp.html#a0853cc05260498d4d6e65dc3a8c7cd99":[4,0,150,56],
-"classIActiveIMMApp.html#a0a00694314e71ade05b31a975276122e":[4,0,150,26],
-"classIActiveIMMApp.html#a0df32a1c293b2137674d9cded142d8d0":[4,0,150,10],
-"classIActiveIMMApp.html#a1133b78ac3a050a149449964aa3e2952":[4,0,150,45],
-"classIActiveIMMApp.html#a1c94fd3182c6a305b8d7e9f6a1b0b4e6":[4,0,150,23],
-"classIActiveIMMApp.html#a21963c7268fd5d5b771c26006d47a887":[4,0,150,18],
-"classIActiveIMMApp.html#a28e6b447cd164e98ec659079e448ccee":[4,0,150,57],
-"classIActiveIMMApp.html#a28ec21e9ba85510b57585038298d88f0":[4,0,150,48],
-"classIActiveIMMApp.html#a2978f828cfe6c32dbf877a8ae1d6a457":[4,0,150,3],
-"classIActiveIMMApp.html#a2bc689c4435dc88afd6a3154408aa942":[4,0,150,46],
-"classIActiveIMMApp.html#a2e71e55d38894821db9c496f6210bfe3":[4,0,150,9],
-"classIActiveIMMApp.html#a31a6eeb6208ffc2ae3b344e6cd734fe4":[4,0,150,33],
-"classIActiveIMMApp.html#a33d95b08656ad0c7238044550fe06f5b":[4,0,150,16],
-"classIActiveIMMApp.html#a357e418c6ced90db6ad098dea82f6d8e":[4,0,150,66],
-"classIActiveIMMApp.html#a38d01e7dfd028d11453a8003bda456e6":[4,0,150,0],
-"classIActiveIMMApp.html#a391870d98d9f63b17bd2cf345484aaff":[4,0,150,2],
-"classIActiveIMMApp.html#a3a5856205afecfb2dd393571e2b564e8":[4,0,150,20],
-"classIActiveIMMApp.html#a3ec2387a9ab537fd16ba5574c16b41f0":[4,0,150,39],
-"classIActiveIMMApp.html#a4321225bb682b677816f583c58dabf65":[4,0,150,64],
-"classIActiveIMMApp.html#a45c21c92ba45fcd85b57ba7ca9f6b4bf":[4,0,150,58],
-"classIActiveIMMApp.html#a4ba0a8c1cfe25f799a61243c661a5c02":[4,0,150,47],
-"classIActiveIMMApp.html#a4dcc45978da1a867e01d8b7a78f7d51a":[4,0,150,53],
-"classIActiveIMMApp.html#a4e4728582faa2a2a0a173797ea29b544":[4,0,150,32],
-"classIActiveIMMApp.html#a4e9f56edffea3be37fd5ff16d0773528":[4,0,150,38],
-"classIActiveIMMApp.html#a4f1f30c5b6e5a8717a8fd90dbfe8b89d":[4,0,150,8],
-"classIActiveIMMApp.html#a536fa372cfe550ab693d80cc0c77ddf8":[4,0,150,21],
-"classIActiveIMMApp.html#a545d0d52f18a22cc3c2b37de62ace489":[4,0,150,67],
-"classIActiveIMMApp.html#a56660547929eb4b75ec54e5cf78b274e":[4,0,150,51],
-"classIActiveIMMApp.html#a56fcfd39069c4ab138462a78d4240a90":[4,0,150,59],
-"classIActiveIMMApp.html#a5709e48e0af74a1565ab0ba562159060":[4,0,150,14],
-"classIActiveIMMApp.html#a618e3f3a213ef32478e4f9cef5954837":[4,0,150,42],
-"classIActiveIMMApp.html#a703381363ab5a14e430d402aae9f3a84":[4,0,150,65],
-"classIActiveIMMApp.html#a70892e110d98716a15b10cc57ea6c349":[4,0,150,35],
-"classIActiveIMMApp.html#a7e66a0a1c11219eab02f984253ae0502":[4,0,150,50],
-"classIActiveIMMApp.html#a85197f32be2f6758205a1b451e462e33":[4,0,150,43],
-"classIActiveIMMApp.html#a85c241c0a4b00dc63705e1e85cd02f59":[4,0,150,31],
-"classIActiveIMMApp.html#a8d9a78559a53e75dfe3a2fcced507fd1":[4,0,150,28]
+"classes.html":[4,1],
+"common.html":[0,3],
+"common.html#common_boxtypes":[0,3,6],
+"common.html#common_buttons":[0,3,0],
+"common.html#common_callbacks":[0,3,8],
+"common.html#common_colors":[0,3,5],
+"common.html#common_custom_boxtypes":[0,3,6,0],
+"common.html#common_groups":[0,3,3],
+"common.html#common_labels":[0,3,7],
+"common.html#common_shortcuts":[0,3,9],
+"common.html#common_sizeposition":[0,3,4],
+"common.html#common_text":[0,3,1],
+"common.html#common_valuators":[0,3,2],
+"cp1133_8h_source.html":[5,0,6],
+"cp1251_8h_source.html":[5,0,7],
+"cp1255_8h_source.html":[5,0,8],
+"cp1256_8h_source.html":[5,0,9],
+"cp936ext_8h_source.html":[5,0,10],
+"deprecated.html":[2],
+"development.html":[0,18],
+"development.html#development_links":[0,18,2],
+"development.html#development_navigation_test":[0,18,4],
+"development.html#development_non-ascii":[0,18,0],
+"development.html#development_paragraphs":[0,18,3],
+"development.html#development_structure":[0,18,1],
+"dingbats___8h_source.html":[5,0,11],
+"dirent_8h_source.html":[5,0,12],
+"drawing.html":[0,5],
+"drawing.html#drawing_colors":[0,5,2],
+"drawing.html#drawing_images":[0,5,3],
+"drawing.html#sect_DrawingFunctions":[0,5,1],
+"drawing.html#sect_WhenCanYouDraw":[0,5,0],
+"drawing.html#ssect_Boxes":[0,5,1,0],
+"drawing.html#ssect_CharacterEncoding":[0,5,2,5],
+"drawing.html#ssect_Clipping":[0,5,1,1],
+"drawing.html#ssect_Complex":[0,5,2,2]
 };
