@@ -1,6 +1,5 @@
 var NAVTREEINDEX6 =
 {
-"classFl__Int__Input.html#a5f648575408e49a803569e46ed45c45a":[4,0,67,0],
 "classFl__JPEG__Image.html":[4,0,68],
 "classFl__JPEG__Image.html#a8a12107808d6e86cd82b7bede8637aeb":[4,0,68,0],
 "classFl__JPEG__Image.html#abd3ae51354599ded511b85a43cf3bbe7":[4,0,68,1],
@@ -249,5 +248,6 @@ var NAVTREEINDEX6 =
 "classFl__Plugin__Manager.html#a4c454afe90d1f532a12d0a9db7de27fe":[4,0,90,5],
 "classFl__Plugin__Manager.html#a8164ddc304b93f62a28c33c3da45af05":[4,0,90,2],
 "classFl__Plugin__Manager.html#a925e0caea1944ad56fded0c4d8f2e1fb":[4,0,90,0],
-"classFl__Positioner.html":[4,0,93]
+"classFl__Positioner.html":[4,0,93],
+"classFl__Positioner.html#a09536d32ff713a0371cefdf602455fe9":[4,0,93,9]
 };
