@@ -1,6 +1,5 @@
 var NAVTREEINDEX8 =
 {
-"classFl__Scroll.html#a24900413c8b600fdc298f44d0821f3e2a4b873bab7be947f316ba3460584253fd":[4,0,110,1],
 "classFl__Scroll.html#a24900413c8b600fdc298f44d0821f3e2a4bb1632c770866fdc7ed8585276ed44a":[4,0,110,3],
 "classFl__Scroll.html#a24900413c8b600fdc298f44d0821f3e2a5e529b94b7f4897f1ccbe9f1be66d7b2":[4,0,110,4],
 "classFl__Scroll.html#a24900413c8b600fdc298f44d0821f3e2aa86133f933846b5579f8cef4ddae10a6":[4,0,110,2],
@@ -80,32 +79,34 @@ var NAVTREEINDEX8 =
 "classFl__Slider.html#ae7f415daaa4fd847ea9998c2917e6df6":[4,0,117,5],
 "classFl__Slider.html#aea633a4c884aa5c3627c25a36e69c103":[4,0,117,1],
 "classFl__Spinner.html":[4,0,118],
-"classFl__Spinner.html#a179c83b7271d1262b34416f14994fdb6":[4,0,118,17],
-"classFl__Spinner.html#a1ac14536a5fe0db55eecbef15d72f9f9":[4,0,118,15],
+"classFl__Spinner.html#a179c83b7271d1262b34416f14994fdb6":[4,0,118,19],
+"classFl__Spinner.html#a1ac14536a5fe0db55eecbef15d72f9f9":[4,0,118,17],
+"classFl__Spinner.html#a21f4de98602bf1967aca0ebb20ed1235":[4,0,118,14],
 "classFl__Spinner.html#a25ee41559aa71f3c1e9d9431d2389348":[4,0,118,3],
 "classFl__Spinner.html#a4e2ea3fbdf8d7653d3dc1440d58434cf":[4,0,118,5],
-"classFl__Spinner.html#a59525ba1c1b9a68324c118ca38dc590b":[4,0,118,21],
-"classFl__Spinner.html#a625d82c7b302e3860dff95389e32c7c9":[4,0,118,20],
+"classFl__Spinner.html#a59525ba1c1b9a68324c118ca38dc590b":[4,0,118,23],
+"classFl__Spinner.html#a625d82c7b302e3860dff95389e32c7c9":[4,0,118,22],
 "classFl__Spinner.html#a6479f39047e9c58f864bf61313288a60":[4,0,118,7],
 "classFl__Spinner.html#a6a860f4ad3e192a235895869a1d7b74b":[4,0,118,6],
 "classFl__Spinner.html#a6ac9be3848bd71cb5919ad1082666073":[4,0,118,11],
 "classFl__Spinner.html#a6d2908d8e037b6e3d73d2e09dedcbe5b":[4,0,118,10],
 "classFl__Spinner.html#a84a1e43149b538ce69a2309aabac0814":[4,0,118,0],
-"classFl__Spinner.html#a89125d570a0d8a5b98056577a5cad14b":[4,0,118,18],
+"classFl__Spinner.html#a89125d570a0d8a5b98056577a5cad14b":[4,0,118,20],
 "classFl__Spinner.html#a93f1c99df8cd04f7d43f382b9e20f786":[4,0,118,13],
-"classFl__Spinner.html#a9457ad1e5c117f7dd56e70f28ff5fe19":[4,0,118,19],
+"classFl__Spinner.html#a9457ad1e5c117f7dd56e70f28ff5fe19":[4,0,118,21],
 "classFl__Spinner.html#aa1e6cace6f88b672a7d8ba219bf0c248":[4,0,118,4],
-"classFl__Spinner.html#aae40d60e85e9d89caf797dd3862cff2b":[4,0,118,24],
+"classFl__Spinner.html#aae40d60e85e9d89caf797dd3862cff2b":[4,0,118,26],
 "classFl__Spinner.html#ab7b053d8d9c92f411c86fe2a15c2631d":[4,0,118,12],
-"classFl__Spinner.html#ac01075ae3d0394d70b2e2f0f3e5593d8":[4,0,118,14],
+"classFl__Spinner.html#ac01075ae3d0394d70b2e2f0f3e5593d8":[4,0,118,16],
+"classFl__Spinner.html#ad1cf5b1e6124f3907e968a5f46e9f214":[4,0,118,15],
 "classFl__Spinner.html#ad6412adc2bad88c13288a7f990fd6bc5":[4,0,118,9],
 "classFl__Spinner.html#adba6f40016702449a41c68183ef9c66e":[4,0,118,8],
-"classFl__Spinner.html#ae00cbda8df08046a8e34bc86be41ace6":[4,0,118,25],
-"classFl__Spinner.html#ae0e2090c56614e15d75de2f7ac13b0cc":[4,0,118,16],
+"classFl__Spinner.html#ae00cbda8df08046a8e34bc86be41ace6":[4,0,118,27],
+"classFl__Spinner.html#ae0e2090c56614e15d75de2f7ac13b0cc":[4,0,118,18],
 "classFl__Spinner.html#ae282c30d012b5e3caf6a192507a81068":[4,0,118,2],
 "classFl__Spinner.html#aeb0fc8ca643e958084dde6c1e699d5b8":[4,0,118,1],
-"classFl__Spinner.html#aef28fc55972ae158f0c115200ee43db8":[4,0,118,22],
-"classFl__Spinner.html#af29b3e59a3ef92aa7f13be5da993000d":[4,0,118,23],
+"classFl__Spinner.html#aef28fc55972ae158f0c115200ee43db8":[4,0,118,24],
+"classFl__Spinner.html#af29b3e59a3ef92aa7f13be5da993000d":[4,0,118,25],
 "classFl__Surface__Device.html":[4,0,119],
 "classFl__Surface__Device.html#a1162e0cf051b2c95dd88091ef3b833df":[4,0,119,2],
 "classFl__Surface__Device.html#a3993b12f96391f224a0d52a1fd15cfee":[4,0,119,3],
@@ -248,6 +249,5 @@ var NAVTREEINDEX8 =
 "classFl__Table.html#acfb1d87d8945045021d6b7406b6a89d1":[4,0,122,83],
 "classFl__Table.html#ad09f503dc6235d7a570b84a1702932c8":[4,0,122,19],
 "classFl__Table.html#ad2e84421bd13c3c72a41c8fa154b3768":[4,0,122,81],
-"classFl__Table.html#ad3d47b28fc87609a01725a78512adf5e":[4,0,122,26],
-"classFl__Table.html#ad51f00bbee634d5ba3c90c67a7c5650a":[4,0,122,59]
+"classFl__Table.html#ad3d47b28fc87609a01725a78512adf5e":[4,0,122,26]
 };
